@@ -1,12 +1,14 @@
+#' Save multiple objects to a file.
+#' 
 #' A simple wrapper for \code{save}. Understands key = value syntax to save 
 #' objects using arbitrary variable names. All options of \code{\link[base]{save}}, 
 #' except \code{list} and \code{envir}, are available and passed to 
 #' \code{\link[base]{save}}.
-#' @title Save multiple objects to a file.
+#' 
+#' @param file 
+#'   File to save.
 #' @param ... [\code{any}]\cr
 #'   Will be converted to an environment and then passed to \code{\link[base]{save}}.
-#' @param file 
-#'   See help of \code{\link[base]{save}}.
 #' @param ascii
 #'   See help of \code{\link[base]{save}}.
 #' @param version
@@ -24,19 +26,20 @@
 #' @examples
 #' x <- 1
 #' save2(y=x, file=tempfile())
-save2 = function(..., file, ascii = FALSE, version = NULL, compress = !ascii, 
-                 compression_level, eval.promises = TRUE, precheck = TRUE) {
-  ddd = list(...)
-  names.ddd = names(ddd)
-  missing.ddd = (names.ddd == "")
-  if(any(missing.ddd)) {
-    names.sub = as.character(substitute(list(...)))[-1L]
-    names.ddd[missing.ddd] = names.sub[missing.ddd]
-    names(ddd) = names.ddd
+save2 = function(file, ..., ascii = FALSE, version = NULL, compress = !ascii, 
+  compression_level, eval.promises = TRUE, precheck = TRUE) {
+  
+  args = list(...)
+  ns = names(args)
+  ns.missing = (ns == "")
+  if(any(ns.missing)) {
+    ns.sub = as.character(substitute(list(...)))[-1L]
+    ns[ns.missing] = ns.sub[ns.missing]
+    names(args) = ns
   }
 
-  ee = tryCatch(as.environment(ddd), 
-                error = function(e) { stop("Unable to convert to environment (", e, ")") })
-  save(list = names.ddd, envir = ee, file = file, ascii = ascii, version = version, compress = compress,
+  ee = tryCatch(as.environment(args), 
+    error = function(e) stopf("Unable to convert to environment (%s)", as.character(e)))
+  save(list = ns, envir = ee, file = file, ascii = ascii, version = version, compress = compress,
        compression_level = compression_level, eval.promises = eval.promises, precheck = precheck)
 }
